@@ -39,10 +39,10 @@ class Cli:
     def update(cls):
         apis.freehub_update()
     @classmethod
-    def download(cls,address,path=None,overwrite=False):
+    def download(cls,address,path=None,overwrite=False,inplace=False):
         path=path or './'
         address=apis.get_complete_address(address)
-        apis.freehub_download(address,path,overwrite=overwrite,quiet=False)
+        apis.freehub_download(address,path,overwrite=overwrite,inplace=inplace,quiet=False)
     @classmethod
     def upload(cls,path,address,overwrite=True):
         address = apis.get_complete_address(address)
